# API Docs

## Sourcemapper

### text _(Source Mapper)_

<p style="word-wrap: break-word">Text to siddhi event source mapper. Transports which accepts text messages can utilize this extensionto convert the incoming text message to Siddhi event. Users can either use the onEventHandler, a pre-defined text format, where event conversion will happen without any configs or regex to map a text message using custom configs.</p>

#### Syntax

```
@source(..., @map(type="text", regex.groupid="<STRING>", fail.on.missing.attribute="<BOOL>", event.grouping.enabled="<BOOL>", delimiter="<STRING>", new.line.character="<STRING>")
```

##### Query Parameters

<table>
    <tr>
        <th>Name</th>
        <th>Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td valign="top">regex.groupid</td>
        <td valign="top"><p style="word-wrap: break-word">Used to specify a regular expression group. Here, groupid can be any capital letter such as regex.A,regex.B .. etc. User can specify any number of regular expression groups and in the attribute annotation,user needs to map all attributes to the regular expression group with the matching group index. If the user needs to enable custom mapping, it is mandatory to specify matching group for each and every attribute.</p></td>
        <td valign="top"></td>
        <td valign="top">STRING</td>
        <td valign="top">No</td>
        <td valign="top">No</td>
    </tr>
    <tr>
        <td valign="top">fail.on.missing.attribute</td>
        <td valign="top"><p style="word-wrap: break-word">This can either have a value of 'true' or 'false'. By default it will be true. This attribute allows user to handle unknown attributes. By default if a regex execution fails or attribute is not present in the event, SP will drop that message. However setting this property to false will prompt DAS to pass 'null' value to that attribute in the event.</p></td>
        <td valign="top">true</td>
        <td valign="top">BOOL</td>
        <td valign="top">Yes</td>
        <td valign="top">No</td>
    </tr>
    <tr>
        <td valign="top">event.grouping.enabled</td>
        <td valign="top"><p style="word-wrap: break-word">This attribute is used to specify whether the event group is enabled or not. If the user needs to receive group of events together and generate multiple siddhi events user can enable this by specifying true.</p></td>
        <td valign="top">false</td>
        <td valign="top">BOOL</td>
        <td valign="top">Yes</td>
        <td valign="top">No</td>
    </tr>
    <tr>
        <td valign="top">delimiter</td>
        <td valign="top"><p style="word-wrap: break-word">This attribute indicates the delimiter of grouped event which is expected to be received. This should be whole line and not a single character.</p></td>
        <td valign="top">~~~~~~~~~~</td>
        <td valign="top">STRING</td>
        <td valign="top">Yes</td>
        <td valign="top">No</td>
    </tr>
    <tr>
        <td valign="top">new.line.character</td>
        <td valign="top"><p style="word-wrap: break-word">This attribute indicates the new line character of the event which is expected to be received. This is used mostly when communication between 2 types of operating systems is expected. For instance as the end of line character linux uses '<br>' while windows use '
<br>'.</p></td>
        <td valign="top">
</td>
        <td valign="top">STRING</td>
        <td valign="top">Yes</td>
        <td valign="top">No</td>
    </tr>
</table>



#### Examples

##### Example 1

```
@source(type='inMemory', topic='stock', @map(type='text'))
define stream FooStream (symbol string, price float, volume long);

```
<p style="word-wrap: break-word">Above configuration will perform a default text input mapping. Expected input should be as follows,symbol:"WSO2",<br>price:55.6,<br>volume:100ORsymbol:'WSO2',<br>price:55.6,<br>volume:100If group events is enabled then input should be as follows,symbol:'WSO2',<br>price:55.6,<br>volume:100<br>~~~~~~~~~~<br>symbol:'WSO2',<br>price:55.6,<br>volume:100</p>

##### Example 2

```
@source(type='inMemory', topic='stock', @map(type='text', fail.on.unknown.attribute = 'true', regex.A='(\w+)\s([-0-9]+)',regex.B='volume\s([-0-9]+)', @attributes(symbol = 'A[1]',price = 'A[2]',volume = 'B' )
```
<p style="word-wrap: break-word">Above configuration will perform a custom text mapping. Expected output would be as follows,wos2 550 volume 100</p>

## Sinkmapper

### text _(Sink Mapper)_

<p style="word-wrap: break-word">Text to Event input mapper. Transports which accepts text messages can utilize this extensionto convert the incoming text message to Siddhi event. Users can either use  a pre-defined text format where event conversion will happen without any configs or use placeholders to map from a custom text message.</p>

#### Syntax

```
@sink(..., @map(type="text", event.grouping.enabled="<BOOL>", delimiter="<STRING>", new.line.character="<STRING>")
```

##### Query Parameters

<table>
    <tr>
        <th>Name</th>
        <th>Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td valign="top">event.grouping.enabled</td>
        <td valign="top"><p style="word-wrap: break-word">This attribute is used to specify whether the event grouping is enabled or not. If user needs to publish a group of events together user can enable this by specifying 'true'.</p></td>
        <td valign="top">false</td>
        <td valign="top">BOOL</td>
        <td valign="top">Yes</td>
        <td valign="top">No</td>
    </tr>
    <tr>
        <td valign="top">delimiter</td>
        <td valign="top"><p style="word-wrap: break-word">This attribute indicates the delimiter of the grouped event which is expected to be received. This should be a whole line not a single character.</p></td>
        <td valign="top">~~~~~~~~~~</td>
        <td valign="top">STRING</td>
        <td valign="top">Yes</td>
        <td valign="top">No</td>
    </tr>
    <tr>
        <td valign="top">new.line.character</td>
        <td valign="top"><p style="word-wrap: break-word">This attribute indicates the new line character ofthe event which is expected to be received. This is used mostly when communication between 2 types of operating systems is expected. For instance as the end of line character linux uses '<br>' while windows use '
<br>'.</p></td>
        <td valign="top">
</td>
        <td valign="top">STRING</td>
        <td valign="top">Yes</td>
        <td valign="top">No</td>
    </tr>
</table>



#### Examples

##### Example 1

```
@sink(type='inMemory', topic='stock', @map(type='text'))
define stream FooStream (symbol string, price float, volume long);

```
<p style="word-wrap: break-word">Above configuration will perform a default text input mapping. Expected output would be as follows,symbol:"WSO2",<br>price:55.6,<br>volume:100orsymbol:'WSO2',<br>price:55.6,<br>volume:100If group events is enabled then the output would be as follows,symbol:'WSO2',<br>price:55.6,<br>volume:100<br>~~~~~~~~~~<br>symbol:'WSO2',<br>price:55.6,<br>volume:100</p>

##### Example 2

```
@sink(type='inMemory', topic='stock', @map(type='text',  @payload(SensorID : {{symbol}}/{{Volume}},
SensorPrice : Rs{{price}}/=,
Value : {{Volume}}ml”)))
```
<p style="word-wrap: break-word">Above configuration will perform a custom text mapping. The output will be as follows,SensorID : wso2/100,<br>SensorPrice : Rs1000/=,<br>Value : 100mlfor the following siddhi event.{wso2,1000,100}</p>

